Textual Snapshot Test Report

### Textual Snapshot Tests

1 snapshots changed 1 snapshots matched
test_inspector_app /Users/aleksandraovchinnikova/PycharmProjects/mrok/tests/agent/sidecar/test_inspector.py:11
View environment info

#### No history for this test

If you're happy with the content on the left, save it to disk by running pytest with the `--snapshot-update` flag.

##### Unexpected?

Snapshots are named after the name of the test you call `snap_compare` in by default.
If you've renamed a test, the association between the snapshot and the test is lost, and you'll need to run with `--snapshot-update` to associate the snapshot with the new test name.

##### More info for test_inspector_app

##### Textual App State

Variable | Value
--- | ---
app.console.legacy_windows | False
app.console.size | ConsoleDimensions(width=80, height=25)

##### Environment (os.environ)

Variable | Value
--- | ---
COMMAND_MODE | unix2003
HOME | /Users/aleksandraovchinnikova
HOMEBREW_CELLAR | /opt/homebrew/Cellar
HOMEBREW_PREFIX | /opt/homebrew
HOMEBREW_REPOSITORY | /opt/homebrew
INFOPATH | /opt/homebrew/share/info:
LANG | C.UTF-8
LC_CTYPE | UTF-8
LOGNAME | aleksandraovchinnikova
OLDPWD | /Users/aleksandraovchinnikova/PycharmProjects/mrok
OSLogRateLimit | 64
PATH | /Users/aleksandraovchinnikova/PycharmProjects/mrok/.venv/bin:/Users/aleksandraovchinnikova/PycharmProjects/mrok/.venv/bin:/opt/homebrew/bin:/opt/homebrew/sbin:/usr/local/bin:/System/Cryptexes/App/usr/bin:/usr/bin:/bin:/usr/sbin:/sbin:/var/run/com.apple.security.cryptexd/codex.system/bootstrap/usr/local/bin:/var/run/com.apple.security.cryptexd/codex.system/bootstrap/usr/bin:/var/run/com.apple.security.cryptexd/codex.system/bootstrap/usr/appleinternal/bin:/usr/local/MacGPG2/bin:/usr/local/share/dotnet:~/.dotnet/tools:/usr/local/munki
PS1 | (mrok) %n@%m %1~ %#
PWD | /Users/aleksandraovchinnikova/PycharmProjects/mrok
REQUESTS_CA_BUNDLE | /opt/homebrew/lib/python3.13/site-packages/certifi/cacert.pem
SHELL | /bin/zsh
SHLVL | 1
SSH_AUTH_SOCK | /private/tmp/com.apple.launchd.8Tvf0kKsbA/Listeners
SSL_CERT_FILE | /opt/homebrew/lib/python3.13/site-packages/certifi/cacert.pem
TERM | xterm-256color
TERMINAL_EMULATOR | JetBrains-JediTerm
TERM_SESSION_ID | 1d55aab3-db9e-4d14-8cc5-d5d42916ac60
TMPDIR | /var/folders/tr/bg4gn1yd3xqd460y65rxkfdh0000gn/T/
USER | aleksandraovchinnikova
UV | /opt/homebrew/bin/uv
UV_RUN_RECURSION_DEPTH | 1
VIRTUAL_ENV | /Users/aleksandraovchinnikova/PycharmProjects/mrok/.venv
VIRTUAL_ENV_PROMPT | (mrok)
XPC_FLAGS | 0x0
XPC_SERVICE_NAME | 0
_ | /opt/homebrew/bin/uv
__CFBundleIdentifier | com.jetbrains.pycharm
__CF_USER_TEXT_ENCODING | 0x1F5:0x0:0x0
PYTEST_VERSION | 8.4.2
TEXTUAL_SNAPSHOT_TEMPDIR | /var/folders/tr/bg4gn1yd3xqd460y65rxkfdh0000gn/T/tmpf84w6p5o

If you're happy with the test output, run pytest with the --snapshot-update flag to update the snapshot.

Report generated at UTC 2025-11-17 02:30:55.331895.